package tech.mercantec.easyeat.ui.dishes

import android.os.Bundle
import android.util.Log
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import tech.mercantec.easyeat.R
import tech.mercantec.easyeat.helpers.ApiRequestException
import tech.mercantec.easyeat.helpers.RecipeDetailsResponse
import tech.mercantec.easyeat.helpers.getRecipeDetails
import kotlin.concurrent.thread
import android.widget.ListView
import android.widget.TextView

class DishDetailsActivity : AppCompatActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_dish_details)

        val dishId = intent.getIntExtra("dish_id", -1)
        if (dishId == -1) {
            Toast.makeText(this, "No dish ID provided", Toast.LENGTH_SHORT).show()
            finish()
            return
        }

        thread {
            val recipe: RecipeDetailsResponse
            try {
                recipe = getRecipeDetails(this, dishId)
            } catch (e: ApiRequestException) {
                runOnUiThread {
                    Toast.makeText(this, e.message, Toast.LENGTH_LONG).show()
                }
                return@thread
            }
            Log.i("DISH", recipe.ingredients.toString())
            runOnUiThread {
                // Set title and description
                findViewById<TextView>(R.id.dishDetailName).text = recipe.name
                findViewById<TextView>(R.id.dishDetailDescription).text = recipe.description

                // Set up the ingredient list
                val ingredientListView = findViewById<ListView>(R.id.dishDetailIngredients)
                val ingredientAdapter = IngredientAdapter(this, recipe.ingredients)
                ingredientListView.adapter = ingredientAdapter

                val instructionsListView = findViewById<ListView>(R.id.dishDetailInstructions)
                val instructionsAdapter = InstructionsAdapter(this, recipe.directions)
                instructionsListView.adapter = instructionsAdapter
            }
        }
    }
}